@@ -9,7 +9,6 @@ from botocore.exceptions import ClientError
 from cmapPy.pandasGEXpress.parse_gct import parse
 from os import environ
 from polly.errors import (
-    BadRequestError,
     error_handler,
     InvalidParameterException,
     MissingKeyException,
@@ -17,13 +16,10 @@ from polly.errors import (
     OperationFailedException,
     paramException,
     AccessDeniedError,
-    InvalidRepoException,
     DatatypeNotFoundException,
     RepositoryNotFoundException,
 )
-from polly.constants import COHORT_CONSTANTS_URL
-import contextlib
-import joblib
+
 import urllib
 import pandas as pd
 import polly.http_response_codes as http_codes
@@ -412,43 +408,6 @@ def elastic_query(index_name: str, dataset_id: str) -> dict:
     return query
 
 
-def get_cohort_constants() -> json:
-    """
-    Returns cohort info from public assests url
-    """
-    response = requests.get(COHORT_CONSTANTS_URL)
-    error_handler(response)
-    return json.loads(response.text)
-
-
-def validate_datatype(datatype: str):
-    """
-    Function to validate datatype of a dataset
-    Returns 1 in case of datatype is Single Cell, 0 otherwise
-    """
-    if datatype == "Single cell":
-        return 1
-    return 0
-
-
-@contextlib.contextmanager
-def tqdm_joblib(tqdm_object):
-    """Context manager to patch joblib to report into tqdm progress bar given as argument"""
-
-    class TqdmBatchCompletionCallback(joblib.parallel.BatchCompletionCallBack):
-        def __call__(self, *args, **kwargs):
-            tqdm_object.update(n=self.batch_size)
-            return super().__call__(*args, **kwargs)
-
-    old_batch_callback = joblib.parallel.BatchCompletionCallBack
-    joblib.parallel.BatchCompletionCallBack = TqdmBatchCompletionCallback
-    try:
-        yield tqdm_object
-    finally:
-        joblib.parallel.BatchCompletionCallBack = old_batch_callback
-        tqdm_object.close()
-
-
 def check_empty(x):
     """
     Function to validate if the entry is an empty list or not.
@@ -549,47 +508,49 @@ def workspaces_permission_check(self, workspace_id) -> bool:
     """
     Function to check access of a user for a given workspace id.
     """
-    permission_url = f"{self.base_url}/workspaces/{workspace_id}/permissions"
-    response = self.session.get(permission_url, params={"include": "user"})
+    permission_url = f"{self.resource_url_search}"
+    payload = {
+        "query": {
+            "bool": {
+                "must": [
+                    {"term": {"id": workspace_id}},
+                    {
+                        "nested": {
+                            "path": "permissions",
+                            "query": {"match": {"permissions.user_id": "{user_id}"}},
+                        }
+                    },
+                ]
+            }
+        }
+    }
+    response = self.session.post(permission_url, data=json.dumps(payload))
     error_handler(response)
-    user_details = get_user_details(self.session, self.base_url_auth)
-    user_id = user_details.get("user_id")
-    if "data" in response.json():
-        json_data = response.json().get("data")
+
+    hits_total_value = response.json()["hits"]["total"].get("value", 0)
+
+    if hits_total_value == 0:
+        raise AccessDeniedError(
+            detail=f"Not enough permissions over the workspace-id {workspace_id}"
+        )
+
+    hits = response.json()["hits"]["hits"]
+
+    if not hits:
+        raise AccessDeniedError(
+            detail=f"Not enough permissions over the workspace-id {workspace_id}"
+        )
+
+    permission = response.json()["hits"]["hits"][0]["_source"]["permissions"][0].get(
+        "access"
+    )
+
+    if permission != "read":
+        return True
     else:
-        raise BadRequestError(detail="Incorrect response format")
-    for user in json_data:
-        if "attributes" in user:
-            attributes = user.get("attributes")
-
-        else:
-            raise BadRequestError(detail="Incorrect response format")
-        if user_id == attributes["user_id"] and attributes["project_id"] == int(
-            workspace_id
-        ):
-            if attributes["permission"] != "read":
-                return True
-            else:
-                raise AccessDeniedError(
-                    detail=f"Read-only permission over the "
-                    f"workspace-id {workspace_id}"
-                )
-    return False
-
-
-def return_entity_type(data_source: str, cohort_info: json) -> str:
-    """
-    Function to return entity type based on the cohort info present in public assets
-    """
-    if data_source not in cohort_info:
-        raise InvalidRepoException(data_source)
-    for repo, dict in cohort_info.items():
-        if data_source == repo:
-            if dict["file_structure"] == "single":
-                entity_type = "dataset"
-            elif dict["file_structure"] == "multiple":
-                entity_type = "sample"
-    return entity_type
+        raise AccessDeniedError(
+            detail=f"Read-only permission over the " f"workspace-id {workspace_id}"
+        )
 
 
 def get_files_in_dir(path_to_dir: str) -> list:
